@@ -24,22 +24,11 @@ __all__ = [
     'healpix_to_xyz',
     'bilinear_interpolation_weights',
     'interpolate_bilinear_lonlat',
+    'boundaries_lonlat',
     'neighbours',
 ]
 
-
-def _restore_shape(*args, **kwargs):
-    shape = kwargs['shape']
-    if shape:
-        if len(args) > 1:
-            return [arg.reshape(shape) for arg in args]
-        else:
-            return args[0].reshape(shape)
-    else:
-        if len(args) > 1:
-            return [arg.item() for arg in args]
-        else:
-            return args[0].item()
+_NUMPY_COPY_IF_NEEDED = False if np.__version__.startswith("1.") else None
 
 
 def _validate_order(order):
@@ -54,12 +43,6 @@ def _validate_order(order):
         raise ValueError("order must be 'nested' or 'ring'")
 
 
-def _validate_healpix_index(label, healpix_index, nside):
-    npix = nside_to_npix(nside)
-    if np.any((healpix_index < 0) | (healpix_index > npix - 1)):
-        raise ValueError(f'{label} must be in the range [0:{npix}]')
-
-
 def _validate_offset(label, offset):
     offset = np.asarray(offset)
     if np.any((offset < 0) | (offset > 1)):
@@ -388,8 +371,8 @@ def healpix_to_lonlat(healpix_index, nside, dx=None, dy=None, order='ring'):
 
     lon, lat = func(healpix_index, nside, dx, dy)
 
-    lon = Longitude(lon, unit=u.rad, copy=False)
-    lat = Latitude(lat, unit=u.rad, copy=False)
+    lon = Longitude(lon, unit=u.rad, copy=_NUMPY_COPY_IF_NEEDED)
+    lat = Latitude(lat, unit=u.rad, copy=_NUMPY_COPY_IF_NEEDED)
 
     return lon, lat
 
